package jp.co.dreamarts.hibiki.smartdb.sample.deletedocument;

import java.io.File;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.configuration.XMLConfiguration;

import jp.co.dreamarts.hibiki.api.common.account.Account;
import jp.co.dreamarts.hibiki.api.common.criteria.HbkCriteria.SortType;
import jp.co.dreamarts.hibiki.api.smartdb.SmartLock;
import jp.co.dreamarts.hibiki.smartdb.api.APIBinder;
import jp.co.dreamarts.hibiki.smartdb.api.APIDocument;
import jp.co.dreamarts.hibiki.smartdb.api.APIItemDefn;
import jp.co.dreamarts.hibiki.smartdb.api.BinderManager;
import jp.co.dreamarts.hibiki.smartdb.api.DocumentManager;
import jp.co.dreamarts.hibiki.smartdb.api.DocumentSearchCondition;
import jp.co.dreamarts.hibiki.smartdb.api.SmartdbAPI;
import jp.co.dreamarts.hibiki.smartdb.api.SortDocumentsBy;
import jp.co.dreamarts.hibiki.smartdb.api.items.ItemTypes;
import jp.co.dreamarts.hibiki.soap.smartdb.BasicInfo;

public class DeleteDocument {

    /**
     * @param args
     */
    public static void main(String[] args) {
        DeleteDocument dd = new DeleteDocument();
        try {
            dd.evacuate();
            System.out.println("処理が完了しました。");
            System.exit(0);
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    /**
     * 有効期限が切れた文書を一括削除するバッチプログラム
     *
     * @throws Exception
     * @since 2.3
     */
    private void evacuate() throws Exception {
        String logMsg;

        /*----------------------------------
         * 一括削除実行前処理
         * 設定ファイル読込＋定義チェック
         *----------------------------------*/
        File file = new File("/etc/hibiki/delete-document.xml");
        if (!file.exists()) {
            System.err.println("設定ファイル /etc/hibiki/delete-document.xml が必要です。");
            System.exit(1);
        }

        XMLConfiguration config = new XMLConfiguration(file);

        String logFilePath = null;
        try {
            logFilePath = config.getString("common-config.logFilePath");
        } catch (Exception e) {
            System.err.println("設定値「common-config.logFilePath」に誤りがあります");
            System.exit(1);
        }
        if (!checkNull(logFilePath)) {
            logMsg = "設定値 common-config.logFilePath がありません。";
            System.err.println(logMsg);
            System.exit(1);
        }

        // 当日日付の取得
        Calendar cal = Calendar.getInstance();
        int year = cal.get(Calendar.YEAR);
        int month = cal.get(Calendar.MONTH) + 1;
        int day = cal.get(Calendar.DATE);
        String date = String.format("%d%02d%02d", year, month, day);

        // ログファイル名の編集
        File logFile = new File(logFilePath + "." + date);

        // デバッグ判定
        String debugValue = config.getString("common-config.debug");
        String debug = "debug";
        if ("on".equals(debugValue)) {
            debug = "";
        }

        // 退避文書の登録者
        int intMid = config.getInt("common-config.updateMid", 0);
        if (intMid == 0) {
            logMsg = "設定値 common-config.updateMid がありません。";
            System.err.println(logMsg);
            System.exit(1);
        } else if (intMid < 1000000 || intMid > 1999999) {
            logMsg = "設定値 common-config.updateMid が正しくありません。";
            System.err.println(logMsg);
            System.exit(1);
        }

        // オリジナル文書のバインダIDを入れる数値入力部品の部品キー
        String binderIdKey = config.getString("common-config.binderIdKey");
        if (!checkNumberAlphabet("common-config.binderIdKey", binderIdKey, 150, true, logFile, debug)) {
            System.exit(1);
        }

        // オリジナル文書のバインダ名を入れる文字列入力部品の部品キー
        String binderNameKey = config.getString("common-config.binderNameKey");
        if (!checkNumberAlphabet("common-config.binderNameKey", binderNameKey, 150, true, logFile,
                debug)) {
            System.exit(1);
        }

        // オリジナル文書の登録者を入れるアカウント選択部品の部品キー
        String regAccountKey = config.getString("common-config.regAccountKey");
        if (!checkNumberAlphabet("common-config.regAccountKey", regAccountKey, 150, true, logFile,
                debug)) {
            System.exit(1);
        }

        // オリジナル文書の登録日時を入れる日付部品の部品キー
        String regDateKey = config.getString("common-config.regDateKey");
        if (!checkNumberAlphabet("common-config.regDateKey", regDateKey, 150, true, logFile, debug)) {
            System.exit(1);
        }

        // オリジナル文書の最終更新者を入れるアカウント選択部品の部品キー
        String lastUpdAccountKey = config.getString("common-config.lastUpdAccountKey");
        if (!checkNumberAlphabet("common-config.lastUpdAccountKey", lastUpdAccountKey, 150, true, logFile,
                debug)) {
            System.exit(1);
        }

        // オリジナル文書の最終更新日時を入れる日付部品部品の部品キー
        String lastUpdDateKey = config.getString("common-config.lastUpdDateKey");
        if (!checkNumberAlphabet("common-config.lastUpdDateKey", lastUpdDateKey, 150, true, logFile,
                debug)) {
            System.exit(1);
        }

        /*----------------------------------------------------
         * Sm@rtDB API読込
         *----------------------------------------------------*/
        SmartdbAPI api = null;
        Account account = null;
        String loginId = null;
        try {
            api = SmartdbAPI.getStandaloneSmartdbAPI();
            account = SmartdbAPI.getAccount(intMid);
            api.setSessionUser(account);
            loginId = account.getLoginId();
            System.out.println("SmartDB 起動成功しました。");
        } catch (Throwable e) {
            System.err.println("SmartDB 起動失敗しました。詳細はhibiki.logを参照してください。");
            System.exit(1);
        }

        // インターフェイスの定義
        BinderManager bman = api.getBinderManager();
        DocumentManager dman = api.getDocumentManager();

        // バインダキーの一覧を取得
        List<String> listAllBinderKeys = bman.getAllBinderKeys();

        /*----------------------------------------------------
         * 退避処理
         *----------------------------------------------------*/
        Object objMoveConfig = config.getProperty("move-config.config.proc");

        // <proc>が読み込めなければ処理終了
        int moveSize;
        if (objMoveConfig == null) {
            moveSize = 0;
            System.out.println("退避処理の記述 move-config.config.proc がありません。");
        } else if (objMoveConfig instanceof Collection) {
            moveSize = ((Collection) objMoveConfig).size();
        } else {
            moveSize = 1;
        }
        loopMove: for (int i = 0; i < moveSize; i++) {

            // 退避数カウント
            int moveCount = 0;

            /*----------------------------------
             * 設定ファイル読込＋定義チェック
             *----------------------------------*/
            String moveConfig = "move-config.config(" + i + ")";

            int cnt = i + 1;

            // プロセス
            String moveProc = moveConfig + ".proc";
            String proc = config.getString(moveProc);
            if (!checkNull(proc) || !proc.equals("move")) {
                // 終了処理
                endProcess("move", cnt, 0, logFile);
                break loopMove;
            }

            // 退避処理を行うバインダキーのキーワード（前方一致）
            String keywordByMoveBinderAllow = moveConfig + ".keywordByMoveBinderAllow";
            String keywordAllow = config.getString(keywordByMoveBinderAllow);

            // 空白が指定された場合は、無制限とする
            boolean allMoveBinder = false;
            if (!checkNull(keywordAllow)) {
                allMoveBinder = true;
            } else if (!checkNumberAlphabet("keywordByMoveBinderAllow", keywordAllow, 150, false, logFile,
                    debug)) {
                // 終了処理
                endProcess("move", cnt, 0, logFile);
                continue loopMove;
            }

            // 退避処理を行わないバインダキーのキーワード（前方一致）
            String keywordByMoveBinderDeny = moveConfig + ".keywordByMoveBinderDeny";
            String keywordDeny = config.getString(keywordByMoveBinderDeny);
            if (!checkNull(keywordDeny)) {
                keywordDeny = "";
            } else if (!checkNumberAlphabet("keywordByMoveBinderDeny", keywordDeny, 150, false, logFile,
                    debug)) {
                // 終了処理
                endProcess("move", cnt, 0, logFile);
                continue loopMove;
            }

            // 退避先バインダのバインダキー
            String moveBinderKey = moveConfig + ".moveBinderKey";
            String moveBinder = config.getString(moveBinderKey);
            if (!checkNumberAlphabet("moveBinderKey", moveBinder, 150, true, logFile, debug)) {
                // 終了処理
                endProcess("move", cnt, 0, logFile);
                continue loopMove;
            }

            // 有効期限を示す「日付選択」部品の「部品キー」
            String expireDateKey = moveConfig + ".expireDateKey";
            String expireDate = config.getString(expireDateKey);
            if (!checkNumberAlphabet("expireDateKey", expireDate, 150, true, logFile, debug)) {
                // 終了処理
                endProcess("move", cnt, 0, logFile);
                continue loopMove;
            }

            // 退避させる文書数の上限
            String highLimit = moveConfig + ".highLimit";
            String limit = config.getString(highLimit);
            boolean noMoveLimit;
            int moveLimitNum = 0;

            // 空白だった場合は制限無し
            if (!checkNull(limit)) {
                noMoveLimit = true;
            } else if (limit.equals("0")) {
                // 終了処理
                endProcess("move", cnt, 0, logFile);
                continue loopMove;
            } else {
                // 半角数字チェック
                if (!checkNumber("highLimit", limit, 0, logFile, debug)) {

                    // 終了処理
                    endProcess("move", cnt, 0, logFile);
                    continue loopMove;
                } else {
                    moveLimitNum = Integer.valueOf(limit).intValue();
                    noMoveLimit = false;
                }
            }

            /*----------------------------------
             * バインダ部品情報チェック
             *----------------------------------*/
            long movePointBinderId = 0;
            // バインダIDの取得
            try {
                movePointBinderId = bman.findBinderIdByKey(moveBinder);
            } catch (Exception e) {
                continue loopMove;
            }

            // バインダ部品情報取得
            boolean toBinderPathKeyCheck = false;
            boolean binderIdKeyCheck = false;
            boolean binderNameKeyCheck = false;
            boolean regAccountKeyCheck = false;
            boolean regDateKeyCheck = false;
            boolean lastUpdAccountKeyCheck = false;
            boolean lastUpdDateKeyCheck = false;

            try {
                Map<String, APIItemDefn> ItemMap = bman.loadKeyItemMap(movePointBinderId);
                Set<String> item = ItemMap.keySet();

                for (String string : item) {
                    String itemKey = string;
                    // オリジナル文書のバインダID
                    if (binderIdKey.equals(itemKey)) {
                        binderIdKeyCheck = true;
                        continue;
                    }
                    // オリジナル文書のバインダ名
                    if (binderNameKey.equals(itemKey)) {
                        binderNameKeyCheck = true;
                        continue;
                    }
                    // オリジナル文書の登録者
                    if (regAccountKey.equals(itemKey)) {
                        regAccountKeyCheck = true;
                        continue;
                    }
                    // オリジナル文書の登録日時
                    if (regDateKey.equals(itemKey)) {
                        regDateKeyCheck = true;
                        continue;
                    }
                    // オリジナル文書の最終更新者
                    if (lastUpdAccountKey.equals(itemKey)) {
                        lastUpdAccountKeyCheck = true;
                        continue;
                    }
                    // オリジナル文書の最終更新日時
                    if (lastUpdDateKey.equals(itemKey)) {
                        lastUpdDateKeyCheck = true;
                        continue;
                    }
                }
            } catch (Exception e) {
                continue loopMove;
            }

            // オリジナル文書のキャビネット階層情報の部品存在チェック
            if (toBinderPathKeyCheck == false) {
                continue loopMove;
            }

            // オリジナル文書のバインダIDの部品存在チェック
            if (binderIdKeyCheck == false) {
                continue loopMove;
            }

            // オリジナル文書のバインダ名の部品存在チェック
            if (binderNameKeyCheck == false) {
                continue loopMove;
            }

            // オリジナル文書の登録者の部品存在チェック
            if (regAccountKeyCheck == false) {
                continue loopMove;
            }

            // オリジナル文書の登録日時の部品チェック
            if (regDateKeyCheck == false) {
                continue loopMove;
            }

            // オリジナル文書の最終更新者の部品チェック
            if (lastUpdAccountKeyCheck == false) {
                continue loopMove;
            }

            // オリジナル文書の最終更新日時の部品チェック
            if (lastUpdDateKeyCheck == false) {
                continue loopMove;
            }

            /*----------------------------------
             * 文書退避処理
             *----------------------------------*/
            loopMoveBinder: for (int i1 = 0; i1 < listAllBinderKeys.size(); i1++) {

                /*----------------------------------
                 * バインダキーの前方一致判定
                 *----------------------------------*/
                String binderKey = listAllBinderKeys.get(i1);

                // バインダキーが設定されていなければスキップ
                if (!checkNull(binderKey)) {
                    continue loopMoveBinder;
                }

                // 前方一致判定
                long moveBinderId = 0;
                if (!selectBinderAllow(binderKey, keywordAllow, keywordDeny, "Move", logFile, "", debug)) {
                    continue loopMoveBinder;
                }

                // バインダIDの取得
                try {
                    moveBinderId = bman.findBinderIdByKey(binderKey);
                } catch (Exception e) {
                    continue loopMoveBinder;
                }

                /*----------------------------------
                 * バインダ部品情報チェック
                 *----------------------------------*/
                boolean expireDateCheck = false;
                try {
                    Map<String, APIItemDefn> ItemMap = bman.loadKeyItemMap(moveBinderId);
                    Set<String> item = ItemMap.keySet();

                    for (String string : item) {
                        String itemKey = string;
                        // 有効期限
                        if (expireDate.equals(itemKey)) {
                            ItemTypes itemType = ItemMap.get(itemKey).getType();
                            ItemTypes dateItemtype = ItemTypes.valueOf("Date");
                            if (itemType.equals(dateItemtype)) {
                                expireDateCheck = true;
                                break;
                            }
                        }
                    }
                } catch (Exception e) {
                    continue loopMoveBinder;
                }

                // 有効期限の日付部品存在チェック
                if (expireDateCheck == false) {
                    continue loopMoveBinder;
                }

                /*----------------------------------
                 * 退避文書の特定
                 *----------------------------------*/

                // 文書検索条件セット
                DocumentSearchCondition searchCondition = dman.createDocumentSearchCondition();

                // バインダID
                searchCondition.withBinderId(moveBinderId);

                // 対象日付の最小値
                Calendar fromCal = Calendar.getInstance();
                fromCal.set(1900, 1, 1);
                Date fromDate = fromCal.getTime();

                // 対象日付の最大値（当日）
                Calendar toCal = Calendar.getInstance();
                toCal.add(Calendar.DATE, -1);
                Date toDate = toCal.getTime();

                // 有効期限
                searchCondition.withDateRange(expireDate, fromDate, toDate);

                // 結果の並び順
                BasicInfo field = BasicInfo.RECORD_ID;
                SortType sortType = SortType.ASC;
                SortDocumentsBy sortOrder = new SortDocumentsBy(field, sortType);

                // オフセット指定
                int offset = 0;

                // 結果文書数の上限
                Integer resultlimit = moveLimitNum;

                // 文書の検索
                List<APIDocument> moveDocument = dman.getSearchResult(searchCondition, sortOrder, offset,
                        resultlimit);

                /*----------------------------------
                 * 文書の退避
                 *----------------------------------*/

                // 退避処理
                if (moveDocument.size() == 0) {
                    continue loopMoveBinder;
                }

                /*----------------------------------
                 * バインダ文書編集ロック処理
                 *----------------------------------*/

                // 権限が無ければバインダ管理者に追加
                APIBinder binder = bman.loadBinder(moveBinderId);

                try {
                    SmartLock smartLock = bman.lockBinderDocuments(moveBinderId);
                    if (smartLock == null) {
                        continue loopMoveBinder;
                    }
                } catch (Exception e) {
                    continue loopMoveBinder;
                }

                loopMoveDoc: for (int i3 = 0; i3 < moveDocument.size(); i3++) {
                    // コピーフラグ初期化
                    int copyFlag = 0;
                    // 退避フラグ初期化
                    int moveFlag = 0;

                    // 文書オブジェクト、レコードID取得
                    APIDocument objDoc;
                    long moveRecordId;
                    try {
                        objDoc = moveDocument.get(i3);
                        moveRecordId = objDoc.getRecordId();
                    } catch (Exception e) {
                        continue loopMoveDoc;
                    }

                    // 対象文書コピー処理
                    APIDocument copyDoc;
                    try {
                        copyDoc = dman.copyDocumentToBinder(objDoc, moveBinder);
                    } catch (Exception e) {
                        continue loopMoveDoc;
                    }

                    /*----------------------------------
                     * 退避先文書への情報追加
                     *----------------------------------*/
                    // バインダ名（文字入力部品）
                    String binderName = binder.getName();

                    // バインダID（数値入力部品）
                    // バインダ名（文字入力部品）
                    // オリジナル文書の登録者（アカウント選択部品）
                    // オリジナル文書の登録日時（日付部品）
                    // オリジナル文書の最終更新者（アカウント選択部品）
                    // オリジナル文書の最終更新日時（日付部品）
                    try {
                        copyDoc.setNumber(binderIdKey, moveBinderId);
                        copyDoc.setText(binderNameKey, binderName);
                        copyDoc.setAccount(regAccountKey, objDoc.getRegAccount());
                        copyDoc.setDate(regDateKey, objDoc.getRegDate());
                        copyDoc.setAccount(lastUpdAccountKey, objDoc.getLastUpdAccount());
                        copyDoc.setDate(lastUpdDateKey, objDoc.getLastUpdDate());
                    } catch (Exception e) {
                        continue loopMoveDoc;
                    }

                    /*----------------------------------
                     * 退避先へ文書の保存
                     *----------------------------------*/
                    try {
                        api.saveDocument(copyDoc);
                    } catch (Exception e) {
                        copyFlag = 1;
                        moveFlag = 1;
                        continue loopMoveDoc;
                    }

                    /*----------------------------------
                     * 元文書の削除
                     * ※保存に成功にした場合のみ
                     *----------------------------------*/
                    if (copyFlag == 0) {
                        try {
                            api.deleteDocument(moveBinderId, moveRecordId);
                            dman.purgeDocument(moveBinderId, moveRecordId);
                        } catch (Exception e) {
                            moveFlag = 1;
                            continue loopMoveDoc;
                        }
                    }

                    // カウントアップ
                    if (moveFlag == 0) {
                        moveCount++;
                    }

                    /*----------------------------------
                     * 退避上限数の判定
                     *----------------------------------*/
                    if (!noMoveLimit) {
                        // 制限数を超えた場合処理終了→次の退避処理へ
                        if (moveLimitNum <= moveCount) {
                            // バインダ文書編集ロック解除処理
                            try {
                                bman.unlockBinderDocuments(moveBinderId);
                            } catch (Exception e) {
                                continue loopMoveBinder;
                            }

                            // 終了処理
                            endProcess("move", cnt, moveCount, logFile);
                            break loopMove;
                        }
                    }

                }

                /*----------------------------------
                 * バインダ文書編集ロック解除処理
                 *----------------------------------*/
                try {
                    bman.unlockBinderDocuments(moveBinderId);
                } catch (Exception e) {
                    continue loopMoveBinder;
                }
            }

            // 終了処理
            endProcess("move", cnt, moveCount, logFile);
        }

        /*----------------------------------------------------
         * 削除処理
         *----------------------------------------------------*/
        Object objDeleteConfig = config.getProperty("delete-config.config.proc");

        // <proc>が読み込めなければ処理終了
        int delSize;
        if (objDeleteConfig == null) {
            System.out.println("削除処理の記述 delete-config.config.proc がありません。");
            delSize = 0;
        } else if (objDeleteConfig instanceof Collection) {
            delSize = ((Collection) objDeleteConfig).size();
        } else {
            delSize = 1;
        }
        loopDelete: for (int j = 0; j < delSize; j++) {

            // 削除数カウント
            int deleteCount = 0;

            /*----------------------------------
             * 設定ファイル読込＋定義チェック
             *----------------------------------*/
            String delConfig = "delete-config.config(" + j + ")";

            int cnt = j + 1;

            // プロセス
            String delProc = delConfig + ".proc";
            String proc = config.getString(delProc);
            if (!checkNull(proc) || !proc.equals("delete")) {
                // ログ出力
                // 終了処理
                endProcess("del", cnt, 0, logFile);
                break loopDelete;
            }

            // 削除処理を行うバインダキーのキーワード（前方一致）
            String keywordByDeleteBinderAllow = delConfig + ".keywordByDeleteBinderAllow";
            String keywordAllow = config.getString(keywordByDeleteBinderAllow);
            if (!checkNumberAlphabet("keywordByDeleteBinderAllow", keywordAllow, 150, false, logFile,
                    debug)) {
                // 終了処理
                endProcess("del", cnt, 0, logFile);
                continue loopDelete;
            }

            // 削除処理を行わないバインダキーのキーワード（前方一致）
            String keywordByDeleteBinderDeny = delConfig + ".keywordByDeleteBinderDeny";
            String keywordDeny = config.getString(keywordByDeleteBinderDeny);
            if (!checkNull(keywordDeny)) {
                keywordDeny = "";
            } else if (!checkNumberAlphabet("keywordByDeleteBinderDeny", keywordDeny, 150, false, logFile,
                    debug)) {
                // 終了処理
                endProcess("del", cnt, 0, logFile);
                continue loopDelete;
            }

            // 有効期限を示す「日付選択」部品の「部品キー」
            String expireDateKey = delConfig + ".expireDateKey";
            String expireDate = config.getString(expireDateKey);
            if (!checkNumberAlphabet("expireDateKey", expireDate, 150, true, logFile, debug)) {
                // 終了処理
                endProcess("del", cnt, 0, logFile);
                continue loopDelete;
            }

            // 削除させる文書数の上限
            String highLimit = delConfig + ".highLimit";
            String limit = config.getString(highLimit);
            boolean noDelLimit;
            int delLimitNum = 0;

            // 空白だった場合は制限無し
            if (!checkNull(limit)) {
                noDelLimit = true;
            } else if (limit.equals("0")) {

                // 終了処理
                endProcess("del", cnt, 0, logFile);
                continue loopDelete;
            } else {
                // 半角数字チェック
                if (!checkNumber("highLimit", limit, 0, logFile, debug)) {

                    // 終了処理
                    endProcess("del", cnt, 0, logFile);
                    continue loopDelete;
                } else {
                    delLimitNum = Integer.valueOf(limit).intValue();
                    noDelLimit = false;
                }
            }

            // 退避バインダに保存しておく猶予期間（日数）
            String extensionDay = delConfig + ".extensionDay";
            String extDay = config.getString(extensionDay);
            boolean noExt;
            int extNum = 0;

            // 空白だった場合は即削除
            if (!checkNull(extDay) || extDay.equals("0")) {
                noExt = true;
            } else {
                // 半角数字チェック
                if (!checkNumber("extensionDay", extDay, 0, logFile, debug)) {

                    // 終了処理
                    endProcess("del", cnt, 0, logFile);
                    continue loopDelete;
                } else {
                    extNum = Integer.valueOf(extDay).intValue();
                    noExt = false;
                }
            }

            // 削除対象の全件フラグ
            String allDeleteFlag = delConfig + ".allDelete";
            String allDelete = config.getString(allDeleteFlag);
            if (!checkNull(allDelete)) {
                allDelete = "";
            }
            if (allDelete.equals("on")) {
            } else {
                if (!checkNull(keywordAllow)) {

                    // 終了処理
                    endProcess("del", cnt, 0, logFile);
                    continue loopDelete;
                }
            }

            /*----------------------------------
             * 文書削除処理
             *----------------------------------*/
            loopDelBinder: for (int j1 = 0; j1 < listAllBinderKeys.size(); j1++) {

                /*----------------------------------
                 * バインダキーの前方一致判定
                 *----------------------------------*/
                String binderKey = listAllBinderKeys.get(j1);

                // バインダキーが設定されていなければスキップ
                if (!checkNull(binderKey)) {
                    continue loopDelBinder;
                }

                // 前方一致判定
                long delBinderId = 0;
                if (!selectBinderAllow(binderKey, keywordAllow, keywordDeny, "Delete", logFile, allDelete,
                        debug)) {
                    continue loopDelBinder;
                }

                // バインダIDの取得
                try {
                    delBinderId = bman.findBinderIdByKey(binderKey);
                } catch (Exception e) {
                    continue loopDelBinder;
                }

                /*----------------------------------
                 * バインダ部品情報チェック
                 *----------------------------------*/
                boolean dateCheck = false;
                try {
                    Map<String, APIItemDefn> ItemMap = bman.loadKeyItemMap(delBinderId);
                    Set<String> item = ItemMap.keySet();
                    for (String string : item) {
                        String itemKey = string;
                        if (expireDate.equals(itemKey)) {
                            ItemTypes itemType = ItemMap.get(itemKey).getType();
                            ItemTypes dateItemtype = ItemTypes.valueOf("Date");
                            if (itemType.equals(dateItemtype)) {
                                dateCheck = true;
                                break;
                            }
                        }
                    }
                } catch (Exception e) {
                    continue loopDelBinder;
                }

                // 日付部品チェック
                if (dateCheck == false) {
                }

                /*----------------------------------
                 * 削除文書の特定
                 *----------------------------------*/
                // 文書検索条件セット
                DocumentSearchCondition searchCondition = dman.createDocumentSearchCondition();

                // バインダID
                searchCondition.withBinderId(delBinderId);

                // 対象日付の最小値
                Calendar fromCal = Calendar.getInstance();
                fromCal.set(1900, 1, 1);
                Date fromDate = fromCal.getTime();

                // 対象日付の最大値
                Calendar toCal = Calendar.getInstance();
                toCal.add(Calendar.DATE, -extNum);
                Date toDate = toCal.getTime();

                // 猶予期間
                searchCondition.withDateRange(expireDate, fromDate, toDate);

                // 結果の並び順
                BasicInfo field = BasicInfo.RECORD_ID;
                SortType sortType = SortType.ASC;
                SortDocumentsBy sortOrder = new SortDocumentsBy(field, sortType);

                // オフセット指定
                int offset = 0;

                // 結果文書数の上限
                Integer resultlimit = delLimitNum;

                // 文書の検索
                List<APIDocument> deleteDocument = dman.getSearchResult(searchCondition, sortOrder, offset,
                        resultlimit);

                /*----------------------------------
                 * 文書の削除
                 *----------------------------------*/

                loopDelDoc: for (int j2 = 0; j2 < deleteDocument.size(); j2++) {
                    // 削除フラグ初期化
                    int delFlag = 0;

                    // 文書オブジェクト、レコードID取得
                    APIDocument objDoc;
                    long delRecordId;
                    try {
                        objDoc = deleteDocument.get(j2);
                        delRecordId = objDoc.getRecordId();
                    } catch (Exception e) {
                        continue loopDelBinder;
                    }

                    // 削除実行
                    try {
                        api.deleteDocument(delBinderId, delRecordId);
                        dman.purgeDocument(delBinderId, delRecordId);
                    } catch (Exception e) {
                        delFlag = 1;
                        continue loopDelDoc;
                    }

                    // カウントアップ
                    if (delFlag == 0) {
                        deleteCount++;
                    }

                    /*----------------------------------
                     * 削除上限数の判定
                     *----------------------------------*/

                    if (!noDelLimit) {
                        // 制限数を超えた場合処理終了→次の退避処理へ
                        if (delLimitNum <= deleteCount) {

                            // 終了処理
                            endProcess("del", cnt, deleteCount, logFile);
                            break loopDelete;
                        }
                    }
                }
            }

            // 終了処理
            endProcess("del", cnt, deleteCount, logFile);
        }

    }

    /**
     * 終了処理
     *
     * @param String proc        処理件数（move/del）
     *        Int num            何個目のプロセスか
     *        Int cnt            件数
     *        File logFile       ログファイル
     * @throws Exception
     * @since 2.3
     */
    private void endProcess(String proc, int num, int cnt, File logFile) throws Exception {
        String logMsg = null;
        String procStr = null;
        if (proc.equals("move")) {
            procStr = "退避";
        } else if (proc.equals("del")) {
            procStr = "削除";
        }

    }

    /**
     * バインダキーの ALLOW or DENY チェック（キーワードの前方一致）
     *
     * @param String binderKey      チェック文字列（バインダキー）
     *        String keywordAllow   Allow（対象とする）キーワード
     *        String keywordDeny    Deny（対象外とする）キーワード
     *        String str            Move（退避処理） or Delete（削除処理）
     *        File   logFile        ログファイル
     *        String allDelete      全削除フラグ（true/false）
     *        String debug          デバッグ判定
     * @return boolean true:対象 false:対象外
     * @throws Exception
     */
    private boolean selectBinderAllow(String binderKey, String keywordAllow, String keywordDeny, String str,
            File logFile, String allDelete, String debug) throws Exception {

        String process = null;
        String logMsg = null;
        if (str.equals("Move")) {
            process = "退避";
        } else if (str.equals("Delete")) {
            process = "削除";
        }

        // 全削除フラグがonだった場合、
        if (allDelete.equals("on")) {
        } else {
            // keywordByXXXXBinderAllowに空白が指定された場合は、無制限とする
            if (!checkNull(keywordAllow)) {
            } else {
                if (!binderKey.startsWith(keywordAllow)) {
                    return false;
                }
            }
        }

        // keywordByXXXXBinderDenyに空白が指定された場合は、除外するバインダは無しとする
        if (!checkNull(keywordDeny)) {
        } else {
            if (binderKey.startsWith(keywordDeny)) {
                return false;
            }
        }

        return true;
    }

    /**
     * Nullチェック
     *
     * @param String  str  チェック元文字列
     * @return boolean true:Nullではない false:Null
     * @throws Exception
     */
    private boolean checkNull(String str) throws Exception {
        // Nullチェック
        if (str == null || str.length() == 0) {
            return false;
        }
        return true;
    }

    /**
     * 半角英数字チェック
     *
     * @param String    key         チェック元文字列のキー
     *        String    str         チェック元文字列
     *        Int       size        文字列のサイズ ※0が指定されてた場合はチェックしない
     *        boolean   nullCheck   空白チェックを行う（true）/行わない（false）
     *        File      logFile     ログファイル
     *        String    debug       デバッグ判定
     * @return boolean true:半角英数字のみ false:半角英数字以外あり
     * @throws Exception
     */
    private boolean checkNumberAlphabet(String key, String str, int size, boolean nullCheck, File logFile,
            String debug) throws Exception {
        String logMsg;

        if (nullCheck == true) {
            // 空白チェック
            if (!checkNull(str)) {
                System.err.println("設定値 " + key + " がありません。");
                return false;
            }
        } else {
            if (!checkNull(str)) {
                return true;
            }
        }

        // 半角英数記号チェック
        for (int i = 0; i < str.length(); i++) {
            char ch = str.charAt(i);
            if (!Character.isLetter(ch) && !Character.isDigit(ch)) {
                System.err.println("設定値 " + key + " に英数字以外の文字を含んでいます。");
                return false;
            }
            if (ch > 0x7e) {
                System.err.println("設定値 " + key + " に英数字以外の文字を含んでいます。");
                return false;
            }
        }

        if (size != 0) {
            // 文字列サイズチェック
            if (str.length() > size) {
                System.err.println("設定値 " + key + " の長さが " + size + " を超えています。");
                return false;
            }
        }

        // 先頭文字チェック
        // ※先頭の1文字は英数字のみ
        String head = str.substring(0, 1);
        if (!head.matches("[a-zA-Z]+")) {
            System.err.println("設定値 " + key + " の先頭文字が英字ではありません。");
            return false;
        }

        return true;
    }

    /**
     * 半角数字チェック
     *
     * @param String key  チェック元文字列のキー
     *        String str  チェック元文字列
     *        Int    size 文字列のサイズ 0が指定されてた場合はチェックしない
     *        File   logFile ログファイル
     *        String    debug       デバッグ判定
     * @return boolean true:半角数字のみ false:半角数字以外あり
     * @throws Exception
     */
    private boolean checkNumber(String key, String str, int size, File logFile, String debug)
            throws Exception {
        String logMsg;

        // 空白チェック
        if (!checkNull(str)) {
            return false;
        }

        // 半角数字チェック
        if (str.matches("[0-9]+")) {
        } else {
            return false;
        }

        // 文字列サイズチェック
        if (size != 0) {
            if (str.length() > size) {
                return false;
            }
        }

        return true;
    }

}