package jp.co.dreamarts.hibiki.smartdb.sample.buttoncustom.docview;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import jp.co.dreamarts.hibiki.api.common.account.Account;
import jp.co.dreamarts.hibiki.smartdb.api.APIDocument;
import jp.co.dreamarts.hibiki.smartdb.api.ButtonBar;
import jp.co.dreamarts.hibiki.smartdb.api.SmartdbAPI;
import jp.co.dreamarts.hibiki.smartdb.api.ButtonBar.ButtonKey;
import jp.co.dreamarts.hibiki.smartdb.api.ButtonBar.InterfaceKey;
import jp.co.dreamarts.hibiki.smartdb.hookpoints.ActionButtonCustomExtensionPoints;

public class ActionButtonCustomExtensionPointsSample extends ActionButtonCustomExtensionPoints {

    public static String DOC_READ_ITEM_KEY = "viewer";

    public static String DOC_READ_ITEM_TYPE = "AccountList";

    public ActionButtonCustomExtensionPointsSample(SmartdbAPI api) {
        super(api);
    }

    @Override
    public void customizeButtonsForDocumentAction(InterfaceKey key, APIDocument doc, ButtonBar buttonBar) {
        // requestとresponseを取得する
        HttpServletRequest request = (HttpServletRequest) getAPI().getContext("request");
        //HttpServletResponse response = (HttpServletResponse) getAPI().getContext("response");

        //Account user = getAPI().getSessionUser();
        if (key.equals(InterfaceKey.DOC_VIEW)) {

            /* ボタンバーの内容を変更、
             * 「編集」「未読」「既読」「閉じる」/「一覧」のみにする
             * 表示条件
             *  アカウント部品(key=viewer)にログインユーザが入っていない
             *  →「編集」　「未読」　「既読」
             *  アカウント部品(key=viewer)にログインユーザが入っている
             *  →「編集」　「閉じる」/「一覧」    
            */
            buttonBar.clear();
            buttonBar.setButtonVisible(ButtonKey.DOC_VIEW_EDIT_BUTTON, true);
            if (canShowReadButton(doc)) {
                List<String> customButtonTemplate = new ArrayList<String>();
                customButtonTemplate.add("/template/sample/custom-button.vm");// velocityファイルパスを設定する
                buttonBar.setCustomButtonTemplateRight(key, customButtonTemplate);

                // Velocity用のパラメーターをrequestに設定
                //request.setAttribute("sampleMid", user.getId());
                request.setAttribute("sampleRecordId", doc.getRecordId());
                request.setAttribute("sampleBinderId", doc.getBinderId());
                request.setAttribute("sampleCsrfToken", getAPI().getHbkSession().getCSRFToken());
            } else {
                buttonBar.setButtonVisible(ButtonKey.DOC_VIEW_CLOSE_BUTTON, true);
                buttonBar.setButtonVisible(ButtonKey.DOC_VIEW_LIST_BUTTON, true);
            }

        }
    }

    private boolean canShowReadButton(APIDocument doc) {
        /* 「未読」　「既読」表示条件
         *  アカウント部品(key=viewer)にログインユーザが入っていない
         *  →「未読」　「既読」を表示にする
         *  アカウント部品(key=viewer)にログインユーザが入っている
         *  →「未読」　「既読」を非表示にする
        */
        boolean showReadButton = true;
        if (DOC_READ_ITEM_TYPE.equals(doc.getItemType(DOC_READ_ITEM_KEY))) {
            Account user = getAPI().getSessionUser();
            try {
                int[] viewerIds = doc.getAccountIds(DOC_READ_ITEM_KEY);
                if (viewerIds == null) {
                    showReadButton = true;
                } else {
                    int len = viewerIds.length;
                    for (int i = 0; i < len; i++) {
                        if (viewerIds[i] == user.getId())
                            return false;
                    }
                }
            } catch (Exception e) {
                // アカウント部品(key=viewer)が存在しない場合、
                //　「未読」「既読」を非表示にする
                showReadButton = false;
            }
        }
        return showReadButton;
    }
}
