package jp.co.dreamarts.hibiki.smartdb.sample.csv2excel;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.Writer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import jp.co.dreamarts.hibiki.api.common.HbkMessageResouces;
import jp.co.dreamarts.hibiki.smartdb.api.csv.APICSVOutputButton;
import jp.co.dreamarts.hibiki.smartdb.api.csv.CSVButtonDisplayType;
import jp.co.dreamarts.hibiki.smartdb.api.csv.APICSVOutputData;
import jp.co.dreamarts.hibiki.smartdb.hookpoints.ReturnType;

public class CSV2ExcelButton extends APICSVOutputButton {

    private Log log = LogFactory.getLog(CSV2ExcelButton.class);

    private String id;

    private CSVButtonDisplayType type;

    private HbkMessageResouces messageTool = HbkMessageResouces.getInstance();

    private String bundle = "CSV2EXCEL_Sample";

    public CSV2ExcelButton(String id, CSVButtonDisplayType type) {
        this.id = id;
        this.type = type;
    }

    @Override
    public String getLabel() {
        return messageTool.get("excel.button", bundle);
    }

    @Override
    public ReturnType convertExportDataFile(long binderId, String binderKey, int viewId,
            APICSVOutputData csvOutputData) {
        FileOutputStream fos = null;
        Writer o = null;
        try {
            File file = csvOutputData.getConvertedDataFile();
            csvOutputData.setContentType("text/plain");
            fos = new FileOutputStream(file);
            o = new OutputStreamWriter(fos, csvOutputData.getCharset());
            o.write("test convert csv to excel");
            csvOutputData.setFileName("Text.txt");
            return ReturnType.OK;
        } catch (Exception e) {
            log.error("Has error when convert csv data to Excel format.", e);
            csvOutputData.setErrorMessage(messageTool.get("excel.button.error", bundle));
            return ReturnType.ERROR;
        } finally {
            try {
                if (o != null) {
                    o.flush();
                }
                if (fos != null) {
                    fos.flush();
                    fos.close();
                }
            } catch (IOException e) {
                log.error("Error!", e);
            }
        }
    }

    @Override
    public CSVButtonDisplayType getType() {
        return type;
    }

    @Override
    public String getId() {
        return id;
    }

    @Override
    public String getConfirmMessage() {
        // 空白を返さないようにください。
        return messageTool.get("excel.button.confirm.message", bundle);
    }

}
