package jp.co.dreamarts.hibiki.smartdb.sample.hookpoints.vote;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.co.dreamarts.hibiki.api.common.account.Account;
import jp.co.dreamarts.hibiki.smartdb.api.APIDocument;
import jp.co.dreamarts.hibiki.smartdb.api.SmartdbAPI;
import jp.co.dreamarts.hibiki.smartdb.api.items.Option;
import jp.co.dreamarts.hibiki.smartdb.hookpoints.DocumentActionHookPoints;
import jp.co.dreamarts.hibiki.smartdb.hookpoints.ReturnType;

import org.apache.commons.beanutils.PropertyUtils;

public class Vote extends DocumentActionHookPoints {
    SmartdbAPI api;

    private static final String UPDATE_CUSTOM_BOTTOM_TEMPLATE = "template/smartdb/addon/vote-update.vm";

    public Vote(SmartdbAPI api) {
        super();
        this.api = api;
    }

    @Override
    public SmartdbAPI getAPI() {
        return api;
    }

    @Override
    public ReturnType beforeUpdate(HttpServletRequest req, HttpServletResponse res, APIDocument doc,
            APIDocument oldDoc) {
        ReturnType ret = ReturnType.OK;

        try {
            Option voteOption = doc.getChoice("vote");
            boolean voted = voteOption != null ? voteOption.getValue() == 10 : false;
            if (!voted && !isAlreadyVoted(doc)) {
                // 投票行為
                doc.addAccountId("voters", api.getSessionUser().getId());
                // 総票数を増やす
                Number counter = doc.getNumber("counter");
                if (counter != null)
                    doc.setNumber("counter", counter.intValue() + 1);
                else
                    doc.setNumber("counter", 1);
                //doc.setNumber("counter", doc.getAccountList("voters").size());
            } else{
                // delete user from voters
                //ログインユーザを削除する
            	//accountList.remove(HbkAccountCache.getCache().getAccount(api.getSessionUser().getId()));
                //doc.addAccountId("voters", api.getSessionUser().getId()); //減らない
                //doc.setAccountList("voters", accountList);
                // 総票を減らす
                Number counter = doc.getNumber("counter");
                if (counter != null) {
                    doc.setNumber("counter", counter.intValue() - 1);
                }
            }
        } catch (Exception e) {
            log.error("Vote binder failed at beforeUpdate()", e);
            ret = ReturnType.DECLINED;
        }
        return ret;
    }

    @Override
    public ReturnType loadData(HttpServletRequest req, HttpServletResponse res, APIDocument doc) {
        ReturnType ret = ReturnType.OK;

        // votersがuserを含む場合は「投票済み」、含まない場合は「未投票」
        try {
            if (isAlreadyVoted(doc))
                doc.setChoice("vote", 10);
            else
                doc.clear("vote");
            // いずれかのボタンを表示する
            req.setAttribute("canVote", true);
            // 投票済みかどうか
            req.setAttribute("isAlreadyVoted", isAlreadyVoted(doc));
            // template
            req.setAttribute("bottomCustomTemplate", UPDATE_CUSTOM_BOTTOM_TEMPLATE);

        } catch (Exception e) {
            log.error("Vote binder failed at loadData()", e);
            ret = ReturnType.DECLINED;
        }
        return ret;
    }

    private boolean isAlreadyVoted(APIDocument doc) throws Exception {
        Account user = api.getSessionUser();
        List<Account> voters = doc.getAccountList("voters");
        if (voters != null)
            for (Account voter : voters)
                if (voter.getId() == user.getId())
                    return true;
        return false;
    }

    @Override
    public ReturnType beforeView(HttpServletRequest req, HttpServletResponse res, APIDocument doc) {
        ReturnType result = ReturnType.DECLINED;
        try {
            // actionFormの値を設定：actionForm.getParts().setVisible("title", false)
            Object actionForm = getRequestAttribute("actionForm");
            if (actionForm == null)
                return result;
            Object parts = PropertyUtils.getSimpleProperty(actionForm, "parts");
            if (parts == null)
                return result;
            Method setVisible = parts.getClass().getMethod("setVisible", String.class, Object.class);
            setVisible.invoke(parts, "title", true);
            result = ReturnType.OK;
        } catch (IllegalAccessException e) {
            log.error("binder 10256 beforeView()処理失敗しました。", e);
        } catch (InvocationTargetException e) {
            log.error("binder 10256 beforeView()処理失敗しました。", e);
        } catch (NoSuchMethodException e) {
            log.error("binder 10256 beforeView()処理失敗しました。", e);
        } catch (Exception e) {
            log.error("binder 10256 beforeView()処理失敗しました。", e);
        }

        return result;
    }

    private Object getRequestAttribute(String name) {
        Object request = api.getContext("request");
        if (request == null)
            return null;
        try {
            Method getAttribute = request.getClass().getMethod("getAttribute", String.class);
            return getAttribute.invoke(request, name);
        } catch (SecurityException e) {
            log.error("getRequestAttribute失敗しました。", e);
        } catch (NoSuchMethodException e) {
            log.error("getRequestAttribute失敗しました。", e);
        } catch (IllegalArgumentException e) {
            log.error("getRequestAttribute失敗しました。", e);
        } catch (IllegalAccessException e) {
            log.error("getRequestAttribute失敗しました。", e);
        } catch (InvocationTargetException e) {
            log.error("getRequestAttribute失敗しました。", e);
        }
        return null;
    }

}
